import { Directive, ElementRef, Input, Output, EventEmitter } from '@angular/core';
/**
 * @element ons-input
 * @directive OnsInput
 * @selector ons-input
 * @description
 *   [en]Angular 2 directive for `<ons-input>` component.[/en]
 *   [ja]`<ons-input>`要素のAngular 2ディレクティブです。[/ja]
 * @example
 *   <ons-input [(value)]="value"></ons-input>
 */
export class OnsInput {
    constructor(_elementRef) {
        this._elementRef = _elementRef;
        /**
         * @output valueChange
         * @type {string}
         * @desc
         *   [en]Triggers when the value is changed.[/en]
         *   [ja]内部の`input`要素の値が変更された時に発火します。[/ja]
         */
        this._valueChange = new EventEmitter();
        this._boundOnChange = this._onChange.bind(this);
        this._element = _elementRef.nativeElement;
        this._element.addEventListener('change', this._boundOnChange);
    }
    _onChange(event) {
        this._valueChange.emit(this._element.value);
    }
    ngOnChanges(changeRecord) {
        const value = changeRecord['_value'].currentValue;
        if (this._element.value !== value) {
            this._element.value = value;
        }
    }
    get element() {
        return this._element;
    }
    get nativeElement() {
        return this._element;
    }
    ngOnDestroy() {
        this._element.removeEventListener('change', this._boundOnChange);
        this._element = null;
    }
}
OnsInput.decorators = [
    { type: Directive, args: [{
                selector: 'ons-input'
            },] },
];
/** @nocollapse */
OnsInput.ctorParameters = () => [
    { type: ElementRef, },
];
OnsInput.propDecorators = {
    '_value': [{ type: Input, args: ['value',] },],
    '_valueChange': [{ type: Output, args: ['valueChange',] },],
};
//# sourceMappingURL=ons-input.js.map