import { Directive, ElementRef, Input, TemplateRef, ViewContainerRef } from '@angular/core';
import * as ons from 'onsenui';
export class ItemContext {
    constructor($implicit, index, count) {
        this.$implicit = $implicit;
        this.index = index;
        this.count = count;
    }
}
/**
 * @element ons-lazy-repeat
 * @directive OnsLazyRepeat
 * @selector [ons-lazy-repeat]
 * @description
 *   [en]Angular 2 directive for `<ons-lazy-repeat>` component.[/en]
 *   [en]`<ons-lazy-repeat>`要素と同じ機能を提供するAngular 2ディレクティブです。[/en]
 * @example
 *   <ons-list>
 *     <ons-list-item *onsLazyRepeat="let item of items; let i = index">
 *       #{{i}} {{item.msg}}
 *     </ons-list-item>
 *   </ons-list>
 */
export class OnsLazyRepeat {
    constructor(_elementRef, _templateRef, _viewContainer) {
        this._elementRef = _elementRef;
        this._templateRef = _templateRef;
        this._viewContainer = _viewContainer;
    }
    /**
     * @input onsLazyRepeat
     * @desc
     *   [en]Render infinite lists with "let of" syntax in Angular 2.[/en]
     *   [ja]let of式を指定します。[/ja]
     * @example
     *  <ons-list>
     *    <ons-list-item *onsLazyRepeat="let message of messages">
     *      {{message}}
     *    </ons-list-item>
     *  </ons-list>
     */
    set onsLazyRepeatOf(value) {
        this._onsLazyRepeatOf = value;
        this._provider = new ons._internal.LazyRepeatProvider(this._elementRef.nativeElement.parentElement, new ons._internal.LazyRepeatDelegate({
            loadItemElement: (index, done) => {
                this._loadItemTemplate(index, done);
            },
            countItems: () => {
                return this._onsLazyRepeatOf.length;
            }
        }));
    }
    _loadItemTemplate(index, done) {
        const context = new ItemContext(this._onsLazyRepeatOf[index], index, this._onsLazyRepeatOf.length);
        const view = this._viewContainer.createEmbeddedView(this._templateRef, context);
        // dirty fix on createEmbeddedView() does not insert DOM element randomly.
        done({ element: view.rootNodes[0] });
    }
    refresh() {
        if (this._provider) {
            this._viewContainer.clear();
            this._provider.refresh();
        }
    }
    ngOnDestroy() {
        if (this._provider) {
            this._provider.destroy();
        }
        this._viewContainer.clear();
        this._provider = null;
    }
}
OnsLazyRepeat.decorators = [
    { type: Directive, args: [{
                selector: '[onsLazyRepeat]'
            },] },
];
/** @nocollapse */
OnsLazyRepeat.ctorParameters = () => [
    { type: ElementRef, },
    { type: TemplateRef, },
    { type: ViewContainerRef, },
];
OnsLazyRepeat.propDecorators = {
    'onsLazyRepeatOf': [{ type: Input },],
};
//# sourceMappingURL=ons-lazy-repeat.js.map