import { Directive, ElementRef, Input, Output, EventEmitter } from '@angular/core';
/**
 * @element ons-range
 * @directive OnsRange
 * @selector ons-range
 * @description
 *   [en]Angular 2 directive for `<ons-range>` component.[/en]
 *   [ja]`<ons-range>`要素のAngular 2ディレクティブです。[/en]
 * @example
 *   <ons-range [(value)]="foo"></ons-range><br>
 *
 *   <!-- Add (input) to change immediately on dragging range component -->
 *   <ons-range [(value)]="bar" (input)="bar = $event.target.value"></ons-range>
 */
export class OnsRange {
    constructor(_elementRef) {
        this._elementRef = _elementRef;
        /**
         * @output valueChange
         * @type {string}
         * @desc
         *   [en]Triggers when the value is changed.[/en]
         *   [ja]値が変更された時に発火します。[/ja]
         */
        this._valueChange = new EventEmitter();
        this._boundOnChange = this._onChange.bind(this);
        this._element = _elementRef.nativeElement;
        this._element.addEventListener('change', this._boundOnChange);
    }
    _onChange(event) {
        this._valueChange.emit(this._element.value);
    }
    ngOnChanges(changeRecord) {
        const value = changeRecord['_value'].currentValue;
        this._element.value = value;
    }
    get element() {
        return this._element;
    }
    get nativeElement() {
        return this._element;
    }
    ngOnDestroy() {
        this._element.removeEventListener('change', this._boundOnChange);
        this._element = null;
    }
}
OnsRange.decorators = [
    { type: Directive, args: [{
                selector: 'ons-range'
            },] },
];
/** @nocollapse */
OnsRange.ctorParameters = () => [
    { type: ElementRef, },
];
OnsRange.propDecorators = {
    '_value': [{ type: Input, args: ['value',] },],
    '_valueChange': [{ type: Output, args: ['valueChange',] },],
};
//# sourceMappingURL=ons-range.js.map