import { Directive, ElementRef, Input, Output, EventEmitter } from '@angular/core';
/**
 * @element ons-switch
 * @directive OnsSwitch
 * @selector ons-switch
 * @description
 *   [en]Angular 2 directive for `<ons-switch>` component.[/en]
 *   [ja]`<ons-switch>`要素のAngular 2ディレクティブです。[/ja]
 * @example
 *   <ons-switch [(value)]="target"></ons-switch>
 */
export class OnsSwitch {
    constructor(_elementRef) {
        this._elementRef = _elementRef;
        /**
         * @output valueChange
         * @type {string}
         * @desc
         *   [en]Triggers when the value is changed.[/en]
         *   [ja]値が変更された時に発火します。[/ja]
         */
        this._valueChange = new EventEmitter();
        this._boundOnChange = this._onChange.bind(this);
        this._element = _elementRef.nativeElement;
        this._element.addEventListener('change', this._boundOnChange);
    }
    /**
     * @input value
     * @type {boolean}
     * @desc
     *   [en]Specify the value of the `<ons-switch>` component.[/en]
     *   [ja]`ons-switch`コンポーネントに設定する値を指定します。[/ja]
     */
    set value(target) {
        this._element.checked = !!target;
    }
    _onChange(event) {
        this._valueChange.emit(this._element.checked);
    }
    ngOnChanges(changeRecord) {
        const value = !!changeRecord.value.currentValue;
        this._element.checked = value;
    }
    get element() {
        return this._element;
    }
    get nativeElement() {
        return this._element;
    }
    ngOnDestroy() {
        this._element.removeEventListener('change', this._boundOnChange);
        this._element = null;
    }
}
OnsSwitch.decorators = [
    { type: Directive, args: [{
                selector: 'ons-switch'
            },] },
];
/** @nocollapse */
OnsSwitch.ctorParameters = () => [
    { type: ElementRef, },
];
OnsSwitch.propDecorators = {
    'value': [{ type: Input, args: ['value',] },],
    '_valueChange': [{ type: Output, args: ['valueChange',] },],
};
//# sourceMappingURL=ons-switch.js.map