import { Injectable, ApplicationRef } from '@angular/core';
export class ComponentLoader {
    constructor(appRef) {
        this.appRef = appRef;
    }
    // Load an instance of ComponentRef in app view.
    load(componentRef) {
        const rootElement = componentRef.location.nativeElement;
        if (this.appRef.attachView) {
            this.appRef.attachView(componentRef.hostView);
            componentRef.onDestroy(() => {
                this.appRef.detachView(componentRef.hostView);
                if (rootElement.parentNode) {
                    rootElement.parentNode.removeChild(rootElement);
                }
            });
        }
        else {
            if (this.appRef.registerChangeDetector) {
                this.appRef.registerChangeDetector(componentRef.changeDetectorRef);
            }
            componentRef.onDestroy(() => {
                if (this.appRef.unregisterChangeDetector) {
                    this.appRef.unregisterChangeDetector(componentRef.changeDetectorRef);
                }
                if (rootElement.parentNode) {
                    rootElement.parentNode.removeChild(rootElement);
                }
            });
        }
        const rootContainer = this.appRef._rootComponents[0].location.nativeElement;
        rootContainer.appendChild(rootElement);
    }
}
ComponentLoader.decorators = [
    { type: Injectable },
];
/** @nocollapse */
ComponentLoader.ctorParameters = () => [
    { type: ApplicationRef, },
];
//# sourceMappingURL=component-loader.js.map