import { Injector, ComponentFactoryResolver, Injectable, ApplicationRef, ReflectiveInjector, NgZone } from '@angular/core';
import { Params } from './params';
import { ComponentLoader } from './component-loader';
/**
 * @object DialogFactory
 */
export class DialogFactory {
    constructor(_injector, _resolver, _appRef, _componentLoader, _zone) {
        this._injector = _injector;
        this._resolver = _resolver;
        this._appRef = _appRef;
        this._componentLoader = _componentLoader;
        this._zone = _zone;
    }
    createDialog(componentType, params = {}) {
        console.warn('[ngx-onsenui] DialogFactory is deprecated since 4.0.0-rc.0. Place <ons-dialog> into your component instead.');
        return new Promise(resolve => {
            setImmediate(() => {
                this._zone.run(() => {
                    const factory = this._resolver.resolveComponentFactory(componentType);
                    const injector = ReflectiveInjector.resolveAndCreate([
                        { provide: Params, useValue: new Params(params) }
                    ], this._injector);
                    const componentRef = factory.create(injector);
                    const rootElement = componentRef.location.nativeElement;
                    this._componentLoader.load(componentRef);
                    const element = rootElement.children[0];
                    const dialogElement = element.tagName === 'ONS-DIALOG' ? element : element.querySelector('ons-dialog');
                    if (!dialogElement) {
                        throw Error('<ons-dialog> element is not found in component\'s template.');
                    }
                    resolve({ dialog: dialogElement, destroy: () => componentRef.destroy() });
                });
            });
        });
    }
}
DialogFactory.decorators = [
    { type: Injectable },
];
/** @nocollapse */
DialogFactory.ctorParameters = () => [
    { type: Injector, },
    { type: ComponentFactoryResolver, },
    { type: ApplicationRef, },
    { type: ComponentLoader, },
    { type: NgZone, },
];
//# sourceMappingURL=dialog-factory.js.map